PreviewData class

打开预览图片需要的数据类型

Constructors

PreviewData({required Type type, String? heroTag, ImageData? image, VideoData? video})
const
PreviewData.fromJson(Map<String, dynamic> json)
factory

Properties

hashCode → int
The hash code for this object.
no setterinherited
heroTag → String?
final
image → ImageData?
final
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited
type → Type
final
video → VideoData?
final

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toJson() → Map<String, dynamic>
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited