VideoData class

Constructors

VideoData({String? coverPath, String? coverUrl, ImageProvider<Object>? coverProvide, String? url, AsyncPath? asyncPath})
const
VideoData.fromJson(Map<String, dynamic> json)
factory

Properties

asyncPath → AsyncPath?
异步获取图片路径
final
coverPath → String?
视频封面缓存路径
final
coverProvide → ImageProvider<Object>?
final
coverUrl → String?
视频封面地址
final
hashCode → int
The hash code for this object.
no setterinherited
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited
url → String?
视频地址
final

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toJson() → Map<String, dynamic>
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited